@@ -23,17 +23,16 @@
 
 #include "ui_PrintOptions.h"
 
-namespace Konsole
-{
+namespace Konsole {
 class PrintOptions : public QWidget, private Ui::PrintOptions
 {
     Q_OBJECT
 
 public:
-    explicit PrintOptions(QWidget* parent = 0);
-    ~PrintOptions();
+    explicit PrintOptions(QWidget *parent = 0);
+    ~PrintOptions() Q_DECL_OVERRIDE;
 
-public slots:
+public Q_SLOTS:
     void saveSettings();
 };
 }
