@@ -83,7 +83,7 @@ QAction* ProfileList::actionForProfile(Profile::Ptr profile) const
 void ProfileList::profileChanged(Profile::Ptr profile)
 {
     QAction* action = actionForProfile(profile);
-    if (action)
+    if (action != nullptr)
         updateAction(action, profile);
 }
 
@@ -102,7 +102,7 @@ void ProfileList::shortcutChanged(Profile::Ptr profile, const QKeySequence& sequ
 
     QAction* action = actionForProfile(profile);
 
-    if (action) {
+    if (action != nullptr) {
         action->setShortcut(sequence);
     }
 }
@@ -127,7 +127,7 @@ void ProfileList::favoriteChanged(Profile::Ptr profile, bool isFavorite)
     ProfileManager* manager = ProfileManager::instance();
 
     if (isFavorite) {
-        QAction* action = new QAction(_group);
+        auto action = new QAction(_group);
         action->setData(QVariant::fromValue(profile));
 
         if (_addShortcuts) {
@@ -143,7 +143,7 @@ void ProfileList::favoriteChanged(Profile::Ptr profile, bool isFavorite)
     } else {
         QAction* action = actionForProfile(profile);
 
-        if (action) {
+        if (action != nullptr) {
             _group->removeAction(action);
             foreach(QWidget * widget, _registeredWidgets) {
                 widget->removeAction(action);
