@@ -22,18 +22,20 @@
 // Own
 #include "ProfileManager.h"
 
+#include "konsoledebug.h"
+
 // Qt
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#include <QtCore/QList>
-#include <QtCore/QString>
+#include <QDir>
+#include <QFileInfo>
+#include <QList>
+#include <QString>
 
 // KDE
 #include <KSharedConfig>
 #include <KConfig>
-#include <QDebug>
 #include <KConfigGroup>
 #include <KLocalizedString>
+#include <KMessageBox>
 
 // Konsole
 #include "ProfileReader.h"
@@ -67,11 +69,15 @@ static void sortByNameProfileList(QList<Profile::Ptr>& list)
 }
 
 ProfileManager::ProfileManager()
-    : _loadedAllProfiles(false)
+    : _profiles(QSet<Profile::Ptr>())
+    , _favorites(QSet<Profile::Ptr>())
+    , _loadedAllProfiles(false)
     , _loadedFavorites(false)
+    , _shortcuts(QMap<QKeySequence, ShortcutData>())
 {
     //load fallback profile
-    _fallbackProfile = Profile::Ptr(new FallbackProfile);
+    _fallbackProfile = Profile::Ptr(new Profile());
+    _fallbackProfile->useFallback();
     addProfile(_fallbackProfile);
 
     // lookup the default profile specified in <App>rc
@@ -110,9 +116,7 @@ ProfileManager::ProfileManager()
     loadShortcuts();
 }
 
-ProfileManager::~ProfileManager()
-{
-}
+ProfileManager::~ProfileManager() = default;
 
 Q_GLOBAL_STATIC(ProfileManager, theProfileManager)
 ProfileManager* ProfileManager::instance()
@@ -135,7 +139,7 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
         return Profile::Ptr();
 
     if (fileInfo.suffix() != QLatin1String("profile"))
-        path.append(".profile");
+        path.append(QLatin1String(".profile"));
     if (fileInfo.path().isEmpty() || fileInfo.path() == QLatin1String("."))
         path.prepend(QLatin1String("konsole") + QDir::separator());
 
@@ -161,7 +165,7 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
     PopStackOnExit<QString> popGuardOnExit(recursionGuard);
 
     if (recursionGuard.contains(path)) {
-        qWarning() << "Ignoring attempt to load profile recursively from" << path;
+        qCDebug(KonsoleDebug) << "Ignoring attempt to load profile recursively from" << path;
         return _fallbackProfile;
     } else {
         recursionGuard.push(path);
@@ -184,7 +188,7 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
     delete reader;
 
     if (!result) {
-        qWarning() << "Could not load profile from " << path;
+        qCDebug(KonsoleDebug) << "Could not load profile from " << path;
         return Profile::Ptr();
     } else {
         addProfile(newProfile);
@@ -236,15 +240,15 @@ void ProfileManager::sortProfiles(QList<Profile::Ptr>& list)
     QList<Profile::Ptr> lackingIndices;
     QList<Profile::Ptr> havingIndices;
 
-    for (int i = 0; i < list.size(); ++i) {
+    for (const auto & i : list) {
         // dis-regard the fallback profile
-        if (list.at(i)->path() == _fallbackProfile->path())
+        if (i->path() == _fallbackProfile->path())
             continue;
 
-        if (list.at(i)->menuIndexAsInt() == 0)
-            lackingIndices.append(list.at(i));
+        if (i->menuIndexAsInt() == 0)
+            lackingIndices.append(i);
         else
-            havingIndices.append(list.at(i));
+            havingIndices.append(i);
     }
 
     // sort by index
@@ -324,8 +328,10 @@ QString ProfileManager::saveProfile(Profile::Ptr profile)
 
     QString newPath = writer->getPath(profile);
 
-    writer->writeProfile(newPath, profile);
-
+    if (!writer->writeProfile(newPath, profile)) {
+        KMessageBox::sorry(0,
+                           i18n("Konsole does not have permission to save this profile to %1", newPath));
+    }
     delete writer;
 
     return newPath;
@@ -362,7 +368,7 @@ void ProfileManager::changeProfile(Profile::Ptr profile,
             newName = QStringLiteral("Profile ") + QString::number(nameSuffix);
             newTranslatedName = i18nc("The default name of a profile", "Profile #%1", nameSuffix);
             // TODO: remove the # above and below - too many issues
-            newTranslatedName.remove('#');
+            newTranslatedName.remove(QLatin1Char('#'));
             nameSuffix++;
         } while (existingProfileNames.contains(newName));
 
@@ -370,7 +376,7 @@ void ProfileManager::changeProfile(Profile::Ptr profile,
         newProfile->clone(profile, true);
         newProfile->setProperty(Profile::UntranslatedName, newName);
         newProfile->setProperty(Profile::Name, newTranslatedName);
-        newProfile->setProperty(Profile::MenuIndex, QString("0"));
+        newProfile->setProperty(Profile::MenuIndex, QStringLiteral("0"));
         newProfile->setHidden(false);
 
         addProfile(newProfile);
@@ -429,7 +435,7 @@ bool ProfileManager::deleteProfile(Profile::Ptr profile)
         // try to delete the config file
         if (profile->isPropertySet(Profile::Path) && QFile::exists(profile->path())) {
             if (!QFile::remove(profile->path())) {
-                qWarning() << "Could not delete profile: " << profile->path()
+                qCDebug(KonsoleDebug) << "Could not delete profile: " << profile->path()
                            << "The file is most likely in a directory which is read-only.";
 
                 return false;
