@@ -23,8 +23,8 @@
 #include "ProfileReader.h"
 
 // Qt
-#include <QtCore/QFile>
-#include <QtCore/QDir>
+#include <QFile>
+#include <QDir>
 
 // KDE
 #include <KConfig>
@@ -37,6 +37,9 @@ using namespace Konsole;
 
 // FIXME: A dup line from Profile.cpp - redo these
 static const char GENERAL_GROUP[]     = "General";
+static const char FEATURES_GROUP[]        = "Terminal Features";
+static const char URLHINTS_KEY[]          = "EnableUrlHints";
+static const char URLHINTSMODIFIERS_KEY[] = "UrlHintsModifiers";
 
 QStringList KDE4ProfileReader::findProfiles()
 {
@@ -47,7 +50,7 @@ QStringList KDE4ProfileReader::findProfiles()
     Q_FOREACH (const QString& dir, dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.profile"));
         Q_FOREACH (const QString& file, fileNames) {
-            profiles.append(dir + '/' + file);
+            profiles.append(dir + QLatin1Char('/') + file);
         }
     }
     return profiles;
@@ -65,7 +68,7 @@ void KDE4ProfileReader::readProperties(const KConfig& config, Profile::Ptr profi
                 groupName = properties->group;
             }
 
-            QString name(properties->name);
+            QString name(QLatin1String(properties->name));
 
             if (group.hasKey(name))
                 profile->setProperty(properties->property,
@@ -94,6 +97,19 @@ bool KDE4ProfileReader::readProfile(const QString& path , Profile::Ptr profile ,
         profile->setProperty(Profile::Arguments, shellCommand.arguments());
     }
 
+    // Check if the user earlier had set the URL hints option, and in that case set the default
+    // URL hints modifier to the earlier default.
+    if (config.hasGroup(FEATURES_GROUP)) {
+        KConfigGroup features = config.group(FEATURES_GROUP);
+        if (features.hasKey(URLHINTS_KEY)) {
+            bool enable = features.readEntry(URLHINTS_KEY, false);
+            if (enable && !features.hasKey(URLHINTSMODIFIERS_KEY)) {
+                features.writeEntry(URLHINTSMODIFIERS_KEY, int(Qt::ControlModifier));
+            }
+            features.deleteEntry(URLHINTS_KEY);
+        }
+    }
+
     profile->setProperty(Profile::UntranslatedName, general.readEntryUntranslated("Name"));
 
     // Read remaining properties
