@@ -23,7 +23,7 @@
 #include "ProfileWriter.h"
 
 // Qt
-#include <QtCore/QFileInfo>
+#include <QFileInfo>
 
 // KDE
 #include <KConfig>
@@ -40,13 +40,11 @@ static const char GENERAL_GROUP[]     = "General";
 // All profiles changes are stored under users' local account
 QString KDE4ProfileWriter::getPath(const Profile::Ptr profile)
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 4, 0)
+    // If any changes are made to this location, check that programs using
+    // the Konsole part can write/save profiles
     static const QString localDataLocation = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/konsole");
-#else
-    static const QString localDataLocation = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
-#endif
 
-    return localDataLocation % "/" % profile->untranslatedName() % ".profile";
+    return localDataLocation % QLatin1String("/") % profile->untranslatedName() % QLatin1String(".profile");
 }
 void KDE4ProfileWriter::writeProperties(KConfig& config,
                                         const Profile::Ptr profile,
@@ -63,7 +61,7 @@ void KDE4ProfileWriter::writeProperties(KConfig& config,
             }
 
             if (profile->isPropertySet(properties->property))
-                group.writeEntry(QString(properties->name),
+                group.writeEntry(QLatin1String(properties->name),
                                  profile->property<QVariant>(properties->property));
         }
 
@@ -74,6 +72,10 @@ bool KDE4ProfileWriter::writeProfile(const QString& path , const Profile::Ptr pr
 {
     KConfig config(path, KConfig::NoGlobals);
 
+    if (!config.isConfigWritable(false)) {
+        return false;
+    }
+
     KConfigGroup general = config.group(GENERAL_GROUP);
 
     // Parent profile if set, when loading the profile in future, the parent
