@@ -22,12 +22,12 @@
 #define SESSIONCONTROLLER_H
 
 // Qt
-#include <QtCore/QList>
-#include <QtCore/QSet>
-#include <QtCore/QPointer>
-#include <QtCore/QString>
-#include <QtCore/QHash>
-#include <QtCore/QRegularExpression>
+#include <QList>
+#include <QSet>
+#include <QPointer>
+#include <QString>
+#include <QHash>
+#include <QRegularExpression>
 
 // KDE
 #include <KXMLGUIClient>
@@ -35,9 +35,9 @@
 // Konsole
 #include "ViewProperties.h"
 #include "Profile.h"
+#include "Enumeration.h"
 
-namespace KIO
-{
+namespace KIO {
 class Job;
 }
 
@@ -52,8 +52,7 @@ class KJob;
 class QAction;
 class KActionMenu;
 
-namespace Konsole
-{
+namespace Konsole {
 class Session;
 class SessionGroup;
 class ScreenWindow;
@@ -61,6 +60,8 @@ class TerminalDisplay;
 class IncrementalSearchBar;
 class ProfileList;
 class RegExpFilter;
+class UrlFilter;
+class FileFilter;
 class EditProfileDialog;
 
 // SaveHistoryTask
@@ -81,17 +82,17 @@ typedef QPointer<Session> SessionPtr;
  * which contains the view to plug the controller's actions into the menu when
  * the view is focused.
  */
-class KONSOLEPRIVATE_EXPORT SessionController : public ViewProperties , public KXMLGUIClient
+class KONSOLEPRIVATE_EXPORT SessionController : public ViewProperties, public KXMLGUIClient
 {
     Q_OBJECT
 
 public:
     enum CopyInputToEnum {
         /** Copy keyboard input to all the other tabs in current window */
-        CopyInputToAllTabsMode = 0 ,
+        CopyInputToAllTabsMode = 0,
 
         /** Copy keyboard input to user selected tabs in current window */
-        CopyInputToSelectedTabsMode = 1 ,
+        CopyInputToSelectedTabsMode = 1,
 
         /** Do not copy keyboard input to other tabs */
         CopyInputToNoneMode = 2
@@ -100,15 +101,18 @@ public:
     /**
      * Constructs a new SessionController which operates on @p session and @p view.
      */
-    SessionController(Session* session , TerminalDisplay* view, QObject* parent);
-    ~SessionController();
+    SessionController(Session *session, TerminalDisplay *view, QObject *parent);
+    ~SessionController() Q_DECL_OVERRIDE;
 
     /** Returns the session associated with this controller */
-    QPointer<Session> session() {
+    QPointer<Session> session()
+    {
         return _session;
     }
+
     /** Returns the view associated with this controller */
-    QPointer<TerminalDisplay>  view()    {
+    QPointer<TerminalDisplay> view()
+    {
         return _view;
     }
 
@@ -139,42 +143,43 @@ public:
      * show() method will be called.  The SessionController will then connect to the search
      * bar's signals to update the search when the widget's controls are pressed.
      */
-    void setSearchBar(IncrementalSearchBar* searchBar);
+    void setSearchBar(IncrementalSearchBar *searchBar);
     /**
      * see setSearchBar()
      */
-    IncrementalSearchBar* searchBar() const;
+    IncrementalSearchBar *searchBar() const;
 
     /**
      * Sets the action displayed in the session's context menu to hide or
      * show the menu bar.
      */
-    void setShowMenuAction(QAction* action);
+    void setShowMenuAction(QAction *action);
 
-    EditProfileDialog* profileDialogPointer();
+    EditProfileDialog *profileDialogPointer();
 
     // reimplemented
-    virtual QUrl url() const;
-    virtual QString currentDir() const;
-    virtual void rename();
-    virtual bool confirmClose() const;
+    QUrl url() const Q_DECL_OVERRIDE;
+    QString currentDir() const Q_DECL_OVERRIDE;
+    void rename() Q_DECL_OVERRIDE;
+    bool confirmClose() const Q_DECL_OVERRIDE;
     virtual bool confirmForceClose() const;
 
     // Reimplemented to watch for events happening to the view
-    virtual bool eventFilter(QObject* watched , QEvent* event);
+    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
 
     /** Returns the set of all controllers that exist. */
-    static QSet<SessionController*> allControllers() {
+    static QSet<SessionController *> allControllers()
+    {
         return _allControllers;
     }
 
-signals:
+Q_SIGNALS:
     /**
      * Emitted when the view associated with the controller is focused.
      * This can be used by other classes to plug the controller's actions into a window's
      * menus.
      */
-    void focused(SessionController* controller);
+    void focused(SessionController *controller);
 
     void rawTitleChanged();
 
@@ -182,9 +187,9 @@ signals:
      * Emitted when the current working directory of the session associated with
      * the controller is changed.
      */
-    void currentDirectoryChanged(const QString& dir);
+    void currentDirectoryChanged(const QString &dir);
 
-public slots:
+public Q_SLOTS:
     /**
      * Issues a command to the session to navigate to the specified URL.
      * This may not succeed if the foreground program does not understand
@@ -194,7 +199,7 @@ public slots:
      * openUrl() currently supports urls for local paths and those
      * using the 'ssh' protocol ( eg. "ssh://joebloggs@hostname" )
      */
-    void openUrl(const QUrl& url);
+    void openUrl(const QUrl &url);
 
     /**
      * update actions which are meaningful only when primary screen is in use.
@@ -204,7 +209,7 @@ public slots:
     /**
      * update actions which are closely related with the selected text.
      */
-    void selectionChanged(const QString& selectedText);
+    void selectionChanged(const QString &selectedText);
 
     /**
      * close the associated session. This might involve user interaction for
@@ -218,7 +223,7 @@ public slots:
     /**  Decrease font size */
     void decreaseFontSize();
 
-private slots:
+private Q_SLOTS:
     // menu item handlers
     void openBrowser();
     void copy();
@@ -226,12 +231,12 @@ private slots:
     void selectAll();
     void selectLine();
     void pasteFromX11Selection(); // shortcut only
-    void copyInputActionsTriggered(QAction* action);
+    void copyInputActionsTriggered(QAction *action);
     void copyInputToAllTabs();
     void copyInputToSelectedTabs();
     void copyInputToNone();
     void editCurrentProfile();
-    void changeCodec(QTextCodec* codec);
+    void changeCodec(QTextCodec *codec);
     void enableSearchBar(bool showSearchBar);
     void searchHistory(bool showSearchBar);
     void searchBarEvent();
@@ -250,30 +255,32 @@ private slots:
     void switchProfile(Profile::Ptr profile);
     void handleWebShortcutAction();
     void configureWebShortcuts();
-    void sendSignal(QAction* action);
+    void sendSignal(QAction *action);
     void sendBackgroundColor();
 
     // other
     void prepareSwitchProfileMenu();
     void updateCodecAction();
-    void showDisplayContextMenu(const QPoint& position);
+    void showDisplayContextMenu(const QPoint &position);
     void movementKeyFromSearchBarReceived(QKeyEvent *event);
     void sessionStateChanged(int state);
     void sessionTitleChanged();
-    void searchTextChanged(const QString& text);
+    void searchTextChanged(const QString &text);
     void searchCompleted(bool success);
     void searchClosed(); // called when the user clicks on the
     // history search bar's close button
 
+    void updateFilterList(Profile::Ptr profile); // Called when the profile has changed, so we might need to change the list of filters
+
     void interactionHandler();
     void snapshot(); // called periodically as the user types
     // to take a snapshot of the state of the
     // foreground process in the terminal
 
     void highlightMatches(bool highlight);
-    void scrollBackOptionsChanged(int mode , int lines);
-    void sessionResizeRequest(const QSize& size);
-    void trackOutput(QKeyEvent* event);  // move view to end of current output
+    void scrollBackOptionsChanged(int mode, int lines);
+    void sessionResizeRequest(const QSize &size);
+    void trackOutput(QKeyEvent *event);  // move view to end of current output
     // when a key press occurs in the
     // display area
 
@@ -286,7 +293,7 @@ private slots:
     bool isKonsolePart() const;
 
     // update actions related with selected text
-    void updateCopyAction(const QString& selectedText);
+    void updateCopyAction(const QString &selectedText);
     void updateWebSearchMenu();
 
 private:
@@ -294,7 +301,7 @@ private:
     // text - pattern to search for
     // direction - value from SearchHistoryTask::SearchDirection enum to specify
     //             the search direction
-    void beginSearch(const QString& text , int direction);
+    void beginSearch(const QString &text, Enum::SearchDirection direction);
     QRegularExpression regexpFromSearchBarOptions() const;
     bool reverseSearchChecked() const;
     void setupCommonActions();
@@ -306,34 +313,36 @@ private:
 private:
     void updateSessionIcon();
 
-    QPointer<Session>         _session;
+    QPointer<Session> _session;
     QPointer<TerminalDisplay> _view;
-    SessionGroup*               _copyToGroup;
+    SessionGroup *_copyToGroup;
 
-    ProfileList* _profileList;
+    ProfileList *_profileList;
 
-    QIcon      _sessionIcon;
-    QString    _sessionIconName;
-    int        _previousState;
+    QIcon _sessionIcon;
+    QString _sessionIconName;
+    int _previousState;
 
-    RegExpFilter*   _searchFilter;
+    RegExpFilter *_searchFilter;
+    UrlFilter *_urlFilter;
+    FileFilter *_fileFilter;
 
-    QAction* _copyInputToAllTabsAction;
+    QAction *_copyInputToAllTabsAction;
 
-    QAction* _findAction;
-    QAction* _findNextAction;
-    QAction* _findPreviousAction;
+    QAction *_findAction;
+    QAction *_findNextAction;
+    QAction *_findPreviousAction;
 
-    QTimer* _interactionTimer;
+    QTimer *_interactionTimer;
 
     int _searchStartLine;
     int _prevSearchResultLine;
     QPointer<IncrementalSearchBar> _searchBar;
 
-    KCodecAction* _codecAction;
+    KCodecAction *_codecAction;
 
-    KActionMenu* _switchProfileMenu;
-    KActionMenu* _webSearchMenu;
+    KActionMenu *_switchProfileMenu;
+    KActionMenu *_webSearchMenu;
 
     bool _listenForScreenWindowUpdates;
     bool _preventClose;
@@ -342,9 +351,9 @@ private:
 
     QString _selectedText;
 
-    QAction* _showMenuAction;
+    QAction *_showMenuAction;
 
-    static QSet<SessionController*> _allControllers;
+    static QSet<SessionController *> _allControllers;
     static int _lastControllerId;
 
     QStringList _bookmarkValidProgramsToClear;
@@ -373,7 +382,7 @@ class SessionTask : public QObject
     Q_OBJECT
 
 public:
-    explicit SessionTask(QObject* parent = 0);
+    explicit SessionTask(QObject *parent = 0);
 
     /**
      * Sets whether the task automatically deletes itself when the task has been finished.
@@ -385,7 +394,7 @@ public:
     bool autoDelete() const;
 
     /** Adds a new session to the group */
-    void addSession(Session* session);
+    void addSession(Session *session);
 
     /**
      * Executes the task on each of the sessions in the group.
@@ -394,7 +403,7 @@ public:
      */
     virtual void execute() = 0;
 
-signals:
+Q_SIGNALS:
     /**
      * Emitted when the task has completed.
      * Depending on the task this may occur just before execute() returns, or it
@@ -423,8 +432,8 @@ class SaveHistoryTask : public SessionTask
 
 public:
     /** Constructs a new task to save session output to URLs */
-    explicit SaveHistoryTask(QObject* parent = 0);
-    virtual ~SaveHistoryTask();
+    explicit SaveHistoryTask(QObject *parent = 0);
+    ~SaveHistoryTask() Q_DECL_OVERRIDE;
 
     /**
      * Opens a save file dialog for each session in the group and begins saving
@@ -432,11 +441,11 @@ public:
      *
      * The data transfer is performed asynchronously and will continue after execute() returns.
      */
-    virtual void execute();
+    void execute() Q_DECL_OVERRIDE;
 
-private slots:
-    void jobDataRequested(KIO::Job* job , QByteArray& data);
-    void jobResult(KJob* job);
+private Q_SLOTS:
+    void jobDataRequested(KIO::Job *job, QByteArray &data);
+    void jobResult(KJob *job);
 
 private:
     class SaveJob // structure to keep information needed to process
@@ -447,11 +456,11 @@ private:
         int lastLineFetched; // the last line processed in the previous data request
         // set this to -1 at the start of the save job
 
-        TerminalCharacterDecoder* decoder;  // decoder used to convert terminal characters
+        TerminalCharacterDecoder *decoder;  // decoder used to convert terminal characters
         // into output
     };
 
-    QHash<KJob*, SaveJob> _jobSession;
+    QHash<KJob *, SaveJob> _jobSession;
 };
 
 //class SearchHistoryThread;
@@ -474,24 +483,13 @@ class SearchHistoryTask : public SessionTask
     Q_OBJECT
 
 public:
-    /**
-     * This enum describes the strategies available for searching through the
-     * session's output.
-     */
-    enum SearchDirection {
-        /** Searches forwards through the output, starting at the current selection. */
-        ForwardsSearch,
-        /** Searches backwards through the output, starting at the current selection. */
-        BackwardsSearch
-    };
-
     /**
      * Constructs a new search task.
      */
-    explicit SearchHistoryTask(QObject* parent = 0);
+    explicit SearchHistoryTask(QObject *parent = 0);
 
     /** Adds a screen window to the list to search when execute() is called. */
-    void addScreenWindow(Session* session , ScreenWindow* searchWindow);
+    void addScreenWindow(Session *session, ScreenWindow *searchWindow);
 
     /** Sets the regular expression which is searched for when execute() is called */
     void setRegExp(const QRegularExpression &regExp);
@@ -499,9 +497,9 @@ public:
     QRegularExpression regExp() const;
 
     /** Specifies the direction to search in when execute() is called. */
-    void setSearchDirection(SearchDirection direction);
+    void setSearchDirection(Enum::SearchDirection direction);
     /** Returns the current search direction.  See setSearchDirection(). */
-    SearchDirection searchDirection() const;
+    Enum::SearchDirection searchDirection() const;
 
     /** The line from which the search will be done **/
     void setStartLine(int startLine);
@@ -516,17 +514,17 @@ public:
      *
      * To continue the search looking for further matches, call execute() again.
      */
-    virtual void execute();
+    void execute() Q_DECL_OVERRIDE;
 
 private:
     typedef QPointer<ScreenWindow> ScreenWindowPtr;
 
-    void executeOnScreenWindow(SessionPtr session , ScreenWindowPtr window);
-    void highlightResult(ScreenWindowPtr window , int position);
+    void executeOnScreenWindow(SessionPtr session, ScreenWindowPtr window);
+    void highlightResult(ScreenWindowPtr window, int position);
 
-    QMap< SessionPtr , ScreenWindowPtr > _windows;
+    QMap< SessionPtr, ScreenWindowPtr > _windows;
     QRegularExpression _regExp;
-    SearchDirection _direction;
+    Enum::SearchDirection _direction;
     int _startLine;
 
     //static QPointer<SearchHistoryThread> _thread;
@@ -534,4 +532,3 @@ private:
 }
 
 #endif //SESSIONCONTROLLER_H
-
