@@ -24,7 +24,7 @@
 #define VT102EMULATION_H
 
 // Qt
-#include <QtCore/QHash>
+#include <QHash>
 
 // Konsole
 #include "Emulation.h"
@@ -49,14 +49,13 @@ class QKeyEvent;
 #define MODE_BracketedPaste  (MODES_SCREEN+13)  // Xterm-style bracketed paste mode
 #define MODE_total           (MODES_SCREEN+14)
 
-namespace Konsole
-{
+namespace Konsole {
 extern unsigned short vt100_graphics[32];
 
 struct CharCodes {
     // coding info
     char charset[4]; //
-    int  cu_cs;      // actual charset.
+    int cu_cs;       // actual charset.
     bool graphic;    // Some VT100 tricks
     bool pound;      // Some VT100 tricks
     bool sa_graphic; // saved graphic
@@ -80,29 +79,29 @@ class Vt102Emulation : public Emulation
 public:
     /** Constructs a new emulation */
     Vt102Emulation();
-    ~Vt102Emulation();
+    ~Vt102Emulation() Q_DECL_OVERRIDE;
 
     // reimplemented from Emulation
-    virtual void clearEntireScreen() Q_DECL_OVERRIDE;
-    virtual void reset() Q_DECL_OVERRIDE;
-    virtual char eraseChar() const Q_DECL_OVERRIDE;
+    void clearEntireScreen() Q_DECL_OVERRIDE;
+    void reset() Q_DECL_OVERRIDE;
+    char eraseChar() const Q_DECL_OVERRIDE;
 
-public slots:
+public Q_SLOTS:
     // reimplemented from Emulation
-    virtual void sendString(const QByteArray& string) Q_DECL_OVERRIDE;
-    virtual void sendText(const QString& text) Q_DECL_OVERRIDE;
-    virtual void sendKeyEvent(QKeyEvent*) Q_DECL_OVERRIDE;
-    virtual void sendMouseEvent(int buttons, int column, int line, int eventType) Q_DECL_OVERRIDE;
-    virtual void focusLost() Q_DECL_OVERRIDE;
-    virtual void focusGained() Q_DECL_OVERRIDE;
+    void sendString(const QByteArray &string) Q_DECL_OVERRIDE;
+    void sendText(const QString &text) Q_DECL_OVERRIDE;
+    void sendKeyEvent(QKeyEvent *) Q_DECL_OVERRIDE;
+    void sendMouseEvent(int buttons, int column, int line, int eventType) Q_DECL_OVERRIDE;
+    void focusLost() Q_DECL_OVERRIDE;
+    void focusGained() Q_DECL_OVERRIDE;
 
 protected:
     // reimplemented from Emulation
-    virtual void setMode(int mode) Q_DECL_OVERRIDE;
-    virtual void resetMode(int mode) Q_DECL_OVERRIDE;
-    virtual void receiveChar(int cc) Q_DECL_OVERRIDE;
+    void setMode(int mode) Q_DECL_OVERRIDE;
+    void resetMode(int mode) Q_DECL_OVERRIDE;
+    void receiveChar(int cc) Q_DECL_OVERRIDE;
 
-private slots:
+private Q_SLOTS:
     //causes changeTitle() to be emitted for each (int,QString) pair in pendingTitleUpdates
     //used to buffer multiple title updates
     void updateTitle();
@@ -170,8 +169,9 @@ private:
     {
     public:
         // Initializes all modes to false
-        TerminalState() {
-            memset(&mode, false, MODE_total * sizeof(bool));
+        TerminalState()
+        {
+            memset(&mode, 0, MODE_total * sizeof(bool));
         }
 
         bool mode[MODE_total];
@@ -186,7 +186,7 @@ private:
     //these calls occur when certain escape sequences are seen in the
     //output from the terminal
     QHash<int, QString> _pendingTitleUpdates;
-    QTimer* _titleUpdateTimer;
+    QTimer *_titleUpdateTimer;
 
     bool _reportFocusEvents;
 };
