@@ -31,7 +31,7 @@ class TerminalCharacterDecoderTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void init();
     void cleanup();
 
